Step 7: Cosmic-ray identification — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Step 7: Cosmic-ray identification

The cosmic rays and bad pixels are now identified by comparing the input images with the associated blotted,median-cleaned images created.

`drizzlepac.drizCR.` `createCorrFile`(outfile, arrlist, template)

  Create a _cor file with the same format as the original input image

  The DQ array will be replaced with the mask array used to create the _cor file.

`drizzlepac.drizCR.` `drizCR`(input=None, configObj=None, editpars=False, **inputDict)

  Look for cosmic rays.

`drizzlepac.drizCR.` `getHelpAsString`()

  Return useful help from a file in the script directory called module.help

`drizzlepac.drizCR.` `run`(configObj)

`drizzlepac.drizCR.` `rundrizCR`(imgObjList, configObj, saveFile=True, procSteps=None)

`drizzlepac.drizCR.` `setDefaults`(configObj={})

  Return a dictionary of the default parameters which also been updated with the user overrides.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »